% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Bernoulli.R
\name{pdf.Bernoulli}
\alias{pdf.Bernoulli}
\alias{log_pdf.Bernoulli}
\title{Evaluate the probability mass function of a Bernoulli distribution}
\usage{
\method{pdf}{Bernoulli}(d, x, drop = TRUE, ...)

\method{log_pdf}{Bernoulli}(d, x, drop = TRUE, ...)
}
\arguments{
\item{d}{A \code{Bernoulli} object created by a call to \code{\link[=Bernoulli]{Bernoulli()}}.}

\item{x}{A vector of elements whose probabilities you would like to
determine given the distribution \code{d}.}

\item{drop}{logical. Should the result be simplified to a vector if possible?}

\item{...}{Arguments to be passed to \code{\link[stats]{dbinom}}.
Unevaluated arguments will generate a warning to catch mispellings or other
possible errors.}
}
\value{
In case of a single distribution object, either a numeric
vector of length \code{probs} (if \code{drop = TRUE}, default) or a \code{matrix} with
\code{length(x)} columns (if \code{drop = FALSE}). In case of a vectorized distribution
object, a matrix with \code{length(x)} columns containing all possible combinations.
}
\description{
Evaluate the probability mass function of a Bernoulli distribution
}
\examples{

set.seed(27)

X <- Bernoulli(0.7)
X

mean(X)
variance(X)
skewness(X)
kurtosis(X)

random(X, 10)
pdf(X, 1)
log_pdf(X, 1)
cdf(X, 0)
quantile(X, 0.7)

cdf(X, quantile(X, 0.7))
quantile(X, cdf(X, 0.7))
}
