% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Binomial.R
\name{quantile.Binomial}
\alias{quantile.Binomial}
\title{Determine quantiles of a Binomial distribution}
\usage{
\method{quantile}{Binomial}(x, probs, drop = TRUE, ...)
}
\arguments{
\item{x}{A \code{Binomial} object created by a call to \code{\link[=Binomial]{Binomial()}}.}

\item{probs}{A vector of probabilities.}

\item{drop}{logical. Shoul the result be simplified to a vector if possible?}

\item{...}{Arguments to be passed to \code{\link[stats]{qbinom}}.
Unevaluated arguments will generate a warning to catch mispellings or other
possible errors.}
}
\value{
In case of a single distribution object, either a numeric
vector of length \code{probs} (if \code{drop = TRUE}, default) or a \code{matrix} with
\code{length(probs)} columns (if \code{drop = FALSE}). In case of a vectorized
distribution object, a matrix with \code{length(probs)} columns containing all
possible combinations.
}
\description{
\code{quantile()} is the inverse of \code{cdf()}.
}
\examples{

set.seed(27)

X <- Binomial(10, 0.2)
X

mean(X)
variance(X)
skewness(X)
kurtosis(X)

random(X, 10)

pdf(X, 2L)
log_pdf(X, 2L)

cdf(X, 4L)
quantile(X, 0.7)

cdf(X, quantile(X, 0.7))
quantile(X, cdf(X, 7))
}
